---
name: "\U0001F381 Feature Request"
about: For the proposal to improve or enhance doccano

---

Feature description
---------
<!-- Please describe the feature: Which area of the library is it related to? What specific solution would you like? -->
